@@ -1,10 +1,10 @@
 # ======================================================================
 #
-# Copyright (C) 2000 Paul Kulchenko (paulclinger@yahoo.com)
+# Copyright (C) 2000-2001 Paul Kulchenko (paulclinger@yahoo.com)
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: SOAP::Transport::LOCAL.pm,v 0.43 2000/11/28 01:47:02 $ 
+# $Id: LOCAL.pm,v 1.3 2001/08/11 19:09:57 paulk Exp $
 #
 # ======================================================================
 
@@ -12,7 +12,7 @@ package SOAP::Transport::LOCAL;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.43';
+$VERSION = eval sprintf("%d.%s", q$Name: release-0_52-public $ =~ /-(\d+)_([\d_]+)/);
 
 # ======================================================================
 
@@ -23,9 +23,9 @@ use vars qw(@ISA);
 
 sub new { 
   my $self = shift;
-  my $class = ref($self) || $self;
 
   unless (ref $self) {
+    my $class = ref($self) || $self;
     my(@params, @methods);
     while (@_) { $class->can($_[0]) ? push(@methods, shift() => shift) : push(@params, shift) }
     $self = $class->SUPER::new(@params);
@@ -44,10 +44,10 @@ sub send_receive {
     @parameters{qw(envelope endpoint action)};
 
   SOAP::Trace::debug($envelope);
-  my $respond = $self->SUPER::handle($envelope);
-  SOAP::Trace::debug($respond);
+  my $response = $self->SUPER::handle($envelope);
+  SOAP::Trace::debug($response);
 
-  $respond;
+  $response;
 }
 
 # ======================================================================
@@ -60,9 +60,13 @@ __END__
 
 SOAP::Transport::LOCAL - Client side no-transport support for SOAP::Lite
 
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =head1 COPYRIGHT
 
-Copyright (C) 2000 Paul Kulchenko. All rights reserved.
+Copyright (C) 2000-2001 Paul Kulchenko. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
